==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/client/AbstractBlockMixin.java <==
package cc.thonly.reverie_dreams.mixin.client;


import cc.thonly.reverie_dreams.TouhouClient;
import net.minecraft.class_10225;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_4970;
import net.minecraft.class_5819;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_4970.class)
public class AbstractBlockMixin {
    @Inject(method = "getStateForNeighborUpdate", cancellable = true, at = @At("HEAD"))
    public void neighborUpdateInject(class_2680 state, class_4538 world, class_10225 tickView, class_2338 pos, class_2350 direction, class_2338 neighborPos, class_2680 neighborState, class_5819 random, CallbackInfoReturnable<class_2680> cir) {
        if (world.method_8608()) {
            if (class_310.method_1551().method_1576() != null)
                if (class_310.method_1551().method_1576().method_3816())
                    if (TouhouClient.SERVER_SIDE_BLOCKS.contains(state.method_26204()))
                        cir.setReturnValue(class_2246.field_10124.method_9564());
        }
    }

    @Inject(method = "onUse", cancellable = true, at = @At("HEAD"))
    public void onUseInject(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit, CallbackInfoReturnable<class_1269> cir) {
        if (world.field_9236) {
            if (class_310.method_1551().method_1576() != null) {
               if (class_310.method_1551().method_1576().method_3816()) {
                    if (TouhouClient.SERVER_SIDE_BLOCKS.contains(state.method_26204())) {
                        cir.setReturnValue(class_1269.field_5814);
                    }
                }
            }

        }
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/mixin/client/AbstractBlockMixin.java <==
package cc.thonly.reverie_dreams.mixin.client;


import cc.thonly.reverie_dreams.ReverieDreamsClient;
import net.minecraft.class_10225;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_310;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_4970;
import net.minecraft.class_5819;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_4970.class)
public class AbstractBlockMixin {
    @Inject(method = "updateShape", cancellable = true, at = @At("HEAD"))
    public void neighborUpdateInject(class_2680 state, class_4538 world, class_10225 tickView, class_2338 pos, class_2350 direction, class_2338 neighborPos, class_2680 neighborState, class_5819 random, CallbackInfoReturnable<class_2680> cir) {
        if (world.method_8608()) {
            if (class_310.method_1551().method_1576() != null)
                if (class_310.method_1551().method_1576().method_3816())
                    if (ReverieDreamsClient.SERVER_SIDE_BLOCKS.contains(state.method_26204()))
                        cir.setReturnValue(class_2246.field_10124.method_9564());
        }
    }

    @Inject(method = "useWithoutItem", cancellable = true, at = @At("HEAD"))
    public void onUseInject(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit, CallbackInfoReturnable<class_1269> cir) {
        if (world.field_9236) {
            if (class_310.method_1551().method_1576() != null) {
               if (class_310.method_1551().method_1576().method_3816()) {
                    if (ReverieDreamsClient.SERVER_SIDE_BLOCKS.contains(state.method_26204())) {
                        cir.setReturnValue(class_1269.field_5814);
                    }
                }
            }

        }
    }
}
